@@ -14,7 +14,7 @@
 unsigned max_bofh=100;
 int max_bofh_ishard=0;
 
-static const char rcsid[]="$Id: bofh.c,v 1.8 2003/09/29 03:52:05 mrsam Exp $";
+static const char rcsid[]="$Id: bofh.c,v 1.9 2004/08/16 23:26:17 mrsam Exp $";
 
 static struct bofh_list *bofh_freemail, *bofh_spamtrap, *bofh_badmx,
 	*bofh_badfrom;
@@ -312,3 +312,38 @@ int bofh_chkbadmx(const char *p)
 	}
 	return (0);
 }
+
+/*
+** Check if an SPF BOFH setting contains the keyword.
+*/
+
+int bofh_checkspf(const char *envvarname,
+		  const char *defaultValue, const char *keyword)
+{
+	char buf[256];
+	const char *p=getenv(envvarname);
+	char *s;
+
+	if (!p || !*p) p=defaultValue;
+
+	buf[0]=0;
+	strncat(buf, p, sizeof(buf)-1);
+
+	for (s=buf; (s=strtok(s, ",")) != NULL; s=NULL)
+		if (strcmp(s, keyword) == 0)
+			return 1;
+	return 0;
+}
+
+/*
+** "all" means any status.
+*/
+
+int bofh_checkspf_status(const char *envvarname,
+			 const char *defaultValue, const char *keyword)
+{
+	if (bofh_checkspf(envvarname, defaultValue, "all") ||
+	    bofh_checkspf(envvarname, defaultValue, keyword))
+		return 1;
+	return 0;
+}
