@@ -1,13 +1,12 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
 #ifndef	cddlvrhost_h
 #define	cddlvrhost_h
 
-#include	"afx.h"
-#include	"afxtempl.h"
+#include	<string>
 
 class rcptinfo;
 class pendelinfo;
@@ -17,7 +16,7 @@ class dlvrhost {
 public:
     dlvrhost *next, *prev;	// next used on hdlvrpfree list, else
 				// this is the first/last list, in MRU order
-    CString hostname;		// Name of this host
+    std::string hostname;	// Name of this host
     unsigned dlvrcount;		// How many deliveries to this host are
 				// in progress
     pendelinfo *pending_list;
