@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2001 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -128,10 +128,8 @@ int	pipe0[2], pipe1[2];
 
 		close(pipe0[1]);
 		close(pipe1[0]);
-		close(0);
-		close(1);
-		dup(pipe0[0]);
-		dup(pipe1[1]);
+		dup2(pipe0[0], 0);
+		dup2(pipe1[1], 1);
 		close(pipe0[0]);
 		close(pipe1[1]);
 
@@ -143,7 +141,8 @@ int	pipe0[2], pipe1[2];
 		clog_msg_start_err();
 		clog_msg_str(strerror(errno));
 		clog_msg_send();
-		write(1, execfailed, sizeof(execfailed)-1);
+		if (write(1, execfailed, sizeof(execfailed)-1) != 1)
+			; /* ignore */
 		exit(1);
 	}
 	close(pipe0[0]);
