@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2004 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -62,6 +62,10 @@ void submit_cancel();
 void submit_cancel_async();	/* This can be called from a signal handler,
 		just before we exit on a signal */
 
+
+void submit_set_teergrube(void (*)(void));
+	/* Set callback function on an error, used to implement teergrube */
+
 #ifdef	__cplusplus
 } ;
 #endif
