@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -704,6 +704,66 @@ static int isfax(const char *p)
 	return (0);
 }
 
+static void print_header(FILE *f, char *template, const char *me,
+			 const char *from_time, const char *from_mta)
+{
+        unsigned char c, c2;
+        int i = 0;
+
+        while ((c=template[i++]) > 0)
+	{
+		char        kw[64];
+		if (c != '[')
+		{
+			putc(c, f);
+                        continue;
+		}
+
+		if (template[i] != '#')
+		{
+			putc('[', f);
+			continue;
+		}
+
+		++i;
+
+		c2=0;
+		while ((c=template[i]) != 0 && (isalnum(c) || c == '_'))
+		{
+                        if (c2 < sizeof(kw)-1)
+                                kw[c2++]=c;
+			++i;
+		}
+		kw[c2]=0;
+
+		if (c != '#')
+		{
+			fprintf(f, "[#%s", kw);
+			continue;
+		}
+
+		++i;
+		if (template[i] != ']')
+		{
+			fprintf(f, "[#%s#", kw);
+			continue;
+		}
+		++i;
+		if (strcmp(kw, "ME") == 0)
+		{
+			fprintf(f, "%s", me);
+		}
+		else if (strcmp(kw, "FROMTIME") == 0)
+		{
+			fprintf(f, "%s", from_time);
+		}
+		else if (strcmp(kw, "FROMMTA") == 0)
+		{
+			fprintf(f, "%s", from_mta);
+		}
+        }
+}
+
 static int dodsn(struct ctlfile *ctf, FILE *fp, const char *sender,
 		int dodelayed)
 {
@@ -799,7 +859,7 @@ const	char *from_time;
 
 	from_time=rfc822_mkdate(stat_buf.st_mtime);
 
-	fprintf(fp, dsnheader, config_me(), from_time,
+	print_header(fp, dsnheader, config_me(), from_time, 
 		from_mta_p && *from_mta_p ? from_mta_p:"unknown");
 
 	if (dodelayed)
