@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2007 Double Precision, Inc.
+** Copyright 1998 - 2008 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -2821,6 +2821,9 @@ const char *p=readline();
 static const char *start_esmtpauth(const char *method, const char *arg,
 	void *voidp)
 {
+	if (arg && !*arg)
+		arg="=";
+
 	if (dowritestr("AUTH ") || dowritestr(method) ||
 			(arg && (dowritestr(" ") || dowritestr(arg))) ||
 			dowritestr("\r\n") ||
@@ -2847,6 +2850,9 @@ static int final_esmtpauth(const char *msg, void *voidp)
 static int plain_esmtpauth(const char *method, const char *arg,
 	void *voidp)
 {
+	if (arg && !*arg)
+		arg="=";
+
 	if (dowritestr("AUTH ") || dowritestr(method) ||
 			(arg && (dowritestr(" ") || dowritestr(arg))) ||
 			dowritestr("\r\n") ||
