@@ -54,7 +54,7 @@
 #include	"liblock/liblock.h"
 #include	"liblock/mail.h"
 
-static const char rcsid[]="$Id: deliver.c,v 1.24 2006/05/28 15:29:52 mrsam Exp $";
+static const char rcsid[]="$Id: deliver.c,v 1.25 2008/11/26 03:57:28 mrsam Exp $";
 
 extern char *local_dotcourier(const char *, const char *, const char **);
 extern char *local_extension();
@@ -842,8 +842,6 @@ const char *shell=getenv("SHELL");
 		}
 		if (newcommand)	free(newcommand);
 
-		if (rc == EX_SOFTWARE)
-			rc=EX_NOPERM;
 		return (rc);
 	}
 	if (newcommand)	free(newcommand);
