@@ -2,7 +2,7 @@
 #
 # TITLE: LDAP
 #
-# $Id: admin-15ldap.pl,v 1.9 2004/10/24 02:01:55 mrsam Exp $
+# $Id: admin-15ldap.pl,v 1.10 2009/01/28 02:55:17 mrsam Exp $
 #
 # Copyright 2001-2004 Double Precision, Inc.  See COPYING for
 # distribution information.
@@ -19,18 +19,19 @@ if ($cgi->param("Save"))
     my $ldap=ReadKWConfigFile("authldaprc");
 
     my $newkw={
-	"LOCATION" => "LDAP_SERVER\t" . param('SERVER') . "\nLDAP_PORT\t" . param('PORT'),
+	"LOCATION" => "LDAP_URI\t" . param('URI'),
 	"LDAP_BASEDN" => "LDAP_BASEDN\t" . param('BASEDN'),
 	"LDAP_BINDDN" => "LDAP_BINDDN\t" . param('BINDDN') . "\nLDAP_BINDPW\t" . $$ldap{'LDAP_BINDPW'},
 	"LDAP_TIMEOUT" => "LDAP_TIMEOUT\t" . param('TIMEOUT'),
 	"LDAP_MAIL" => "LDAP_MAIL\t" . param('MAIL'),
 	"LDAP_HOMEDIR" => "LDAP_HOMEDIR\t" . param('HOMEDIR'),
-	"LDAP_PW" => "LDAP_CLEARPW\t" . param('CLEARPW') . "\nLDAP_CRYPTPW\t" . param('CRYPTPW')
+	"LDAP_PW" => "LDAP_CLEARPW\t" . param('CLEARPW') . "\nLDAP_CRYPTPW\t" . param('CRYPTPW'),
+	"LDAP_FILTER" => "LDAP_FILTER\t" . param('FILTER'),
 	} ;
 
     $errstr="\@REQUIRED\@"
 	unless required
-		 ('SERVER', 'PORT', 'BASEDN', 'TIMEOUT', 'MAIL', 'HOMEDIR') &&
+		 ('URI', 'BASEDN', 'TIMEOUT', 'MAIL', 'HOMEDIR') &&
 		     (param('CLEARPW') || param('CRYPTPW')) &&
 			 (param('UID') || param('GLOB_UID')) &&
 			     (param('GID') || param('GLOB_GID'));
@@ -78,7 +79,7 @@ display_form("admin-15ldap.html",
 	     {
 		 "ERROR" => $errstr,
 
-		 "SERVER" => $$ldap{'LDAP_SERVER'},
+		 "URI" => $$ldap{'LDAP_URI'},
 		 "PORT" => $$ldap{'LDAP_PORT'},
 		 "BASEDN" => $$ldap{'LDAP_BASEDN'},
 
@@ -100,5 +101,6 @@ display_form("admin-15ldap.html",
 		 "CRYPTPW" => $$ldap{'LDAP_CRYPTPW'},
 		 "UID" => $$ldap{'LDAP_UID'},
 		 "GID" => $$ldap{'LDAP_GID'},
+		 "FILTER" => $$ldap{'LDAP_FILTER'},
 	     }
 	     );
