@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2004 Double Precision, Inc.
+** Copyright 1998 - 2008 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -17,13 +17,15 @@
 #include	"courierauthsasl.h"
 #include	"courierauthdebug.h"
 
-static const char rcsid[]="$Id: authenticate_auth.c,v 1.11 2004/11/21 03:32:12 mrsam Exp $";
+static const char rcsid[]="$Id: authenticate_auth.c,v 1.12 2008/06/29 20:18:36 mrsam Exp $";
 
 extern int main_argc;
 extern char **main_argv;
 
 extern int login_callback(struct authinfo *ainfo, void *dummy);
 
+extern const char *imap_externalauth();
+
 static char *send_auth_reply(const char *q, void *dummy)
 {
 	struct imaptoken *tok;
@@ -106,14 +108,17 @@ int	rc;
 			return (0);
 		}
 		initreply=my_strdup(tok->tokenbuf);
+		if (strcmp(initreply, "=") == 0)
+			*initreply=0;
 		tok=nexttoken_nouc();
 	}
 
 	if (tok->tokentype != IT_EOL)	return (0);
 
 	read_eol();
-	if ((rc = auth_sasl(authmethod, initreply, &send_auth_reply, NULL,
-		      &authtype, &authdata)) != 0)
+	if ((rc = auth_sasl_ex(authmethod, initreply, imap_externalauth(),
+			       &send_auth_reply, NULL,
+			       &authtype, &authdata)) != 0)
 	{
 		free(authmethod);
 		if (initreply)
