@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2003 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -67,7 +67,7 @@
 #include	"unicode/unicode.h"
 #include	"courierauth.h"
 
-static const char rcsid[]="$Id: mailboxlist.c,v 1.19 2004/10/21 00:45:35 mrsam Exp $";
+static const char rcsid[]="$Id: mailboxlist.c,v 1.20 2007/07/27 02:41:01 mrsam Exp $";
 
 static const char hierchs[]={HIERCH, 0};
 
@@ -183,6 +183,7 @@ int mailbox_scan(const char *reference, const char *name,
 }
 
 static int match_mailbox(char *, char *, int flags);
+static void match_mailbox_prep(char *);
 
 /* Check if a folder has any new messages */
 
@@ -285,21 +286,76 @@ struct hierlist *p;
 static void hier_entry(char *folder,
 		       struct hierlist **hierarchies);
 
-static void folder_entry(char *folder, char *hier,
+static int has_hier_entry(char *folder,
+			  struct hierlist **hierarchies);
+
+static void folder_entry(char *folder, char *pattern,
 			 int list_options,
 			 struct hierlist **folders,
 			 struct hierlist **hierarchies)
 {
+	size_t i;
+	size_t folder_l=strlen(folder);
+
+	int need_add_hier;
+	int need_add_folders;
+
+	match_mailbox_prep(folder);
+
+	/* Optimize away folders we don't care about */
+
+	for (i=0; pattern[i]; i++)
+	{
+		if ((!(list_options & LIST_CHECK1FOLDER)) &&
+		    (pattern[i] == '%' || pattern[i] == '*'))
+		{
+			while (i)
+			{
+				if (pattern[i] == HIERCH)
+					break;
+				--i;
+			}
+			break;
+		}
+	}
+
+	if (folder_l <= i)
+	{
+		if (memcmp(folder, pattern, folder_l))
+			return;
+
+		if (folder_l != i && pattern[folder_l] != HIERCH)
+			return;
+	}
+	else if (i)
+	{
+		if (memcmp(folder, pattern, i))
+			return;
+		if (folder[i] != HIERCH)
+			return;
+	}
+
+	need_add_folders=0;
+
+	if (match_mailbox(folder, pattern, list_options) == 0)
+		need_add_folders=1;
+
+	need_add_hier=0;
+	if (!has_hier_entry(folder, hierarchies))
+		need_add_hier=1;
+
+	if (!need_add_folders && !need_add_hier)
+		return; /* Nothing to do */
+
 	CHECK_RIGHTSM(folder, have_rights, ACL_LOOKUP);
 	if (!have_rights[0])
 		return;
 
-	if (match_mailbox(folder, hier, list_options) == 0)
-	{
+	if (need_add_folders)
 		(void) add_hier(folders, folder);
-	}
 
-	hier_entry(folder, hierarchies);
+	if (need_add_hier)
+		hier_entry(folder, hierarchies);
 }
 
 static void hier_entry(char *folder,
@@ -316,6 +372,25 @@ static void hier_entry(char *folder,
 	}
 }
 
+static int has_hier_entry(char *folder,
+			  struct hierlist **hierarchies)
+{
+	unsigned i;
+
+	for (i=0; folder[i]; i++)
+	{
+		if (folder[i] != HIERCH)	continue;
+		folder[i]=0;
+		if (!search_hier(*hierarchies, folder))
+		{
+			folder[i]=HIERCH;
+			return (0);
+		}
+		folder[i]=HIERCH;
+	}
+	return (1);
+}
+
 struct list_sharable_info {
 	char *pattern;
 	struct hierlist **folders, **hierarchies;
@@ -787,6 +862,8 @@ int callback_rc=0;
 	hierarchies=0;
 	folders=0;
 
+	match_mailbox_prep(pattern);
+
 	shared_info.pattern=pattern;
 	shared_info.folders= &folders;
 	shared_info.hierarchies= &hierarchies;
@@ -874,6 +951,8 @@ int callback_rc=0;
 	{
 		hierarchies=hp->next;
 
+		match_mailbox_prep(hp->hier);
+
 		if (match_mailbox(hp->hier, pattern, list_options) == 0
 		    && hp->flag == 0)
 		{
@@ -919,7 +998,7 @@ int callback_rc=0;
 
 static int match_recursive(char *, char *, int);
 
-static int match_mailbox(char *name, char *pattern, int list_options)
+static void match_mailbox_prep(char *name)
 {
 	size_t	i;
 
@@ -935,26 +1014,16 @@ static int match_mailbox(char *name, char *pattern, int list_options)
 		for (i=0; name[i] && name[i] != HIERCH; i++)
 			name[i]=toupper( (int)(unsigned char)name[i] );
 
-	if (
-#if	HAVE_STRNCASECMP
-	    strncasecmp(pattern, INBOX, sizeof(INBOX)-1) == 0
-#else
-	    strnicmp(pattern, INBOX, sizeof(INBOX)-1) == 0
-#endif
-	    )
-		for (i=0; pattern[i] && pattern[i] != HIERCH; i++)
-			pattern[i]=toupper( (int)(unsigned char)pattern[i] );
-
 	/* ... except that "shared" should be lowercase ... */
 
 	if (memcmp(name, "SHARED", 6) == 0)
 		memcpy(name, "shared", 6);
+}
 
-	if (memcmp(pattern, "SHARED", 6) == 0)
-		memcpy(pattern, "shared", 6);
-
-	if (list_options & LIST_CHECK1FOLDER)
-		return strcmp(name, pattern);
+static int match_mailbox(char *name, char *pattern, int list_options)
+{
+        if (list_options & LIST_CHECK1FOLDER)
+                return strcmp(name, pattern);
 
 	return (match_recursive(name, pattern, HIERCH));
 }
