@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.
+** Copyright 1998 - 2008 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -26,74 +26,61 @@
 #include	<courierauthdebug.h>
 #include	<courierauthsasl.h>
 #include	"tcpd/spipe.h"
+#include	"numlib/numlib.h"
+#include	"tcpd/tlsclient.h"
 
-static const char rcsid[]="$Id: pop3login.c,v 1.21 2008/01/05 02:58:36 mrsam Exp $";
+static const char rcsid[]="$Id: pop3login.c,v 1.23 2008/06/29 20:18:36 mrsam Exp $";
 
 extern void pop3dcapa();
 extern int have_starttls();
 extern int tls_required();
+extern const char *pop3_externalauth();
+
 static const char *pop3d;
 static const char *defaultmaildir;
 
 static int	starttls()
 {
-	int	pipefd[2];
-	pid_t	p;
-	int	waitstat;
+	char *argvec[4];
+
+	char localfd_buf[NUMBUFSIZE+40];
+	char buf2[NUMBUFSIZE];
+	struct couriertls_info cinfo;
+	int pipefd[2];
 
 	if (libmail_streampipe(pipefd))
 	{
-		printf("-ERR libmail_streampipe() failed.");
+		printf("-ERR libmail_streampipe() failed.\r\n");
 		return (-1);
 	}
 
-	p=fork();
-	if (p == -1)
-	{
-		close(pipefd[0]);
-		close(pipefd[1]);
-		printf("-ERR fork() failed.");
-		return (-1);
-	}
+	couriertls_init(&cinfo);
+	fcntl(pipefd[0], F_SETFD, FD_CLOEXEC);
 
-	if (p == 0)
-	{
-	char	buf1[100];
-	char	dummy;
+	strcat(strcpy(localfd_buf, "-localfd="),
+	       libmail_str_size_t(pipefd[1], buf2));
 
-		/*
-		** Fork once more, and let the parent exit,
-		** so that courieresmtpd doesn't have this
-		** child process.
-		*/
-
-		p=fork();
-		if (p == -1)
-		{
-			perror("fork");
-			exit(1);
-		}
-		if (p)	exit(0);
-
-		close(pipefd[0]);
-		sprintf(buf1, "-localfd=%d", (int)pipefd[1]);
-		if (read(pipefd[1], &dummy, 1) != 1)
-			exit(0);
-
-		/* couriertls will have the socket on fd 0,
-		** and dup stderr on fd 1 */
-
-		dup2(2, 1);
-		alarm(0);
-		execl( getenv("COURIERTLS"), "couriertls",
-			buf1, "-tcpd", "-server", (char *)0);
-		fprintf(stderr, "ERR: COURIERTLS exec(%s) failed!!\n",
-					 getenv("COURIERTLS"));
-		exit(1);
-	}
+	argvec[0]=localfd_buf;
+	argvec[1]="-tcpd";
+	argvec[2]="-server";
+	argvec[3]=NULL;
 
 	printf("+OK Begin SSL/TLS negotiation now.\r\n");
 	fflush(stdout);
+
+	if (couriertls_start(argvec, &cinfo))
+	{
+		close(pipefd[0]);
+		close(pipefd[1]);
+		printf("-ERR STARTTLS failed: %s\r\n",
+		       cinfo.errmsg);
+		couriertls_destroy(&cinfo);
+		return (-1);
+	}
+
+	couriertls_export_subject_environment(&cinfo);
+	couriertls_destroy(&cinfo);
+
 	close(pipefd[1]);
 	close(0);
 	close(1);
@@ -103,14 +90,10 @@ static int	starttls()
 		exit(1);
 	}
 	close(pipefd[0]);
-	if (write(1, "", 1) < 0)	/* child - exec OK now */
-		; /* make gcc shut up */
 
-	while (wait(&waitstat) != p)
-		;
 	putenv("POP3_STARTTLS=NO");
 	putenv("POP3_TLS_REQUIRED=0");
-	putenv("POP3_STLS=1");
+	putenv("POP3_TLS=1");
 	return (0);
 }
 
@@ -276,6 +259,7 @@ char *q ;
 
 	fflush(stdout);
 	fflush(stderr);
+	alarm(60);
 	while (fgets(buf, sizeof(buf), stdin))
 	{
 		c=1;
@@ -362,11 +346,23 @@ char *q ;
 
 				if (method)
 				{
-				char *initreply=strtok(0, " \t\r");
-				int	rc=auth_sasl(method, initreply,
-						     authresp,
-						     NULL,
-						     &authtype, &authdata);
+					char *initreply=strtok(0, " \t\r");
+					int	rc;
+					char *p;
+
+					for (p=method; *p; p++)
+						*p=toupper(*p);
+
+					if (initreply &&
+					    strcmp(initreply, "=") == 0)
+						initreply="";
+
+					rc=auth_sasl_ex(method, initreply,
+							pop3_externalauth(),
+							authresp,
+							NULL,
+							&authtype,
+							&authdata);
 
 					if (rc == 0)
 					{
