@@ -1,9 +1,9 @@
 /*
-** Copyright 2001-2003 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: pcpd.c,v 1.16 2004/05/02 14:59:42 mrsam Exp $";
+static const char rcsid[]="$Id: pcpd.c,v 1.18 2006/01/23 23:22:10 mrsam Exp $";
 
 #include "config.h"
 #include "pcp.h"
@@ -2231,7 +2231,7 @@ static char *login(int, int *);
 static int accept_sock(int sock)
 {
 	struct sockaddr_un saddr;
-	int saddr_len;
+	socklen_t saddr_len;
 
 	saddr_len=sizeof(saddr);
 
@@ -2412,8 +2412,8 @@ static char *login(int isprivate,
 						r=q+1;
 				*r=0;
 
-				rc=auth_login(uinfo.userid, p,
-					      callback_login, &uinfo);
+				rc=authpcp_login(uinfo.userid, p,
+						 callback_login, &uinfo);
 
 				if (rc)
 				{
@@ -2443,8 +2443,8 @@ static char *login(int isprivate,
 		{
 			if ((p=strtok(NULL, " ")) != NULL)
 			{
-				int rc= auth_userid(p, callback_userid,
-						    &uinfo);
+				int rc= authpcp_userid(p, callback_userid,
+						       &uinfo);
 
 				if (rc)
 				{
@@ -2503,8 +2503,8 @@ static char *login(int isprivate,
 				}
 
 				uinfo.isproxy=1;
-				rc=auth_userid(uinfo.userid, callback_login,
-					       &uinfo);
+				rc=authpcp_userid(uinfo.userid, callback_login,
+						  &uinfo);
 				if (rc)
 				{
 					fprintf(stderr,
@@ -2548,8 +2548,9 @@ static char *login(int isprivate,
 				** we don't care.
 				*/
 
-				rc=auth_userid(uinfo.userid, callback_login,
-					       &uinfo);
+				rc=authpcp_userid(uinfo.userid,
+						  callback_login,
+						  &uinfo);
 
 				if (rc)
 				{
