@@ -1,10 +1,11 @@
 /*
-** Copyright 2000-2006 Double Precision, Inc.
+** Copyright 2000-2008 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 #include	"config.h"
 #include	"argparse.h"
 #include	"spipe.h"
+
 #include	"libcouriertls.h"
 #include	"tlscache.h"
 #include	"rfc1035/rfc1035.h"
@@ -48,10 +49,6 @@
 #endif
 #include	<sys/socket.h>
 #include	<arpa/inet.h>
-#define	DEBUG_SAFESTACK	1	/* For openssl 0.9.6 */
-
-#include	<openssl/ssl.h>
-#include	<openssl/err.h>
 
 #if TIME_WITH_SYS_TIME
 #include        <sys/time.h>
@@ -65,7 +62,7 @@
 #endif
 #include	<locale.h>
 
-static const char rcsid[]="$Id: starttls.c,v 1.36 2007/03/06 04:45:57 mrsam Exp $";
+static const char rcsid[]="$Id: starttls.c,v 1.43 2008/06/29 20:18:36 mrsam Exp $";
 
 /* Command-line options: */
 const char *clienthost=0;
@@ -93,7 +90,7 @@ static void nonsslerror(const char *pfix)
 	fprintf(errfp, "%s: %s\n", pfix, strerror(errno));
 }
 
-void docopy(SSL *ssl, int sslfd, int stdinfd, int stdoutfd)
+void docopy(ssl_handle ssl, int sslfd, int stdinfd, int stdoutfd)
 {
 	struct tls_transfer_info transfer_info;
 
@@ -203,133 +200,94 @@ void docopy(SSL *ssl, int sslfd, int stdinfd, int stdoutfd)
 	}
 }
 
-#define MAXDOMAINSIZE	256
+struct dump_capture_subject {
+	char line[1024];
+	int line_size;
 
-static time_t asn1toTime(ASN1_TIME *asn1Time)
+	int set_subject;
+	int seen_subject;
+	int in_subject;
+	FILE *fp;
+};
+
+static void dump_to_fp(const char *p, int cnt, void *arg)
 {
-	struct tm tm;
-	int offset;
+	struct dump_capture_subject *dcs=(struct dump_capture_subject *)arg;
+	char *n, *v;
+	char namebuf[64];
 
-	if (asn1Time == NULL || asn1Time->length < 13)
-		return 0;
+	if (cnt < 0)
+		cnt=strlen(p);
 
-	memset(&tm, 0, sizeof(tm));
+	if (dcs->fp && fwrite(p, cnt, 1, dcs->fp) != 1)
+		; // NOOP
 
-#define N2(n)	((asn1Time->data[n]-'0')*10 + asn1Time->data[(n)+1]-'0')
-
-#define CPY(f,n) (tm.f=N2(n))
-
-	CPY(tm_year,0);
-
-	if(tm.tm_year < 50)
-		tm.tm_year += 100; /* Sux */
-
-	CPY(tm_mon, 2);
-	--tm.tm_mon;
-	CPY(tm_mday, 4);
-	CPY(tm_hour, 6);
-	CPY(tm_min, 8);
-	CPY(tm_sec, 10);
-
-	offset=0;
-
-	if (asn1Time->data[12] != 'Z')
+	while (cnt)
 	{
-		if (asn1Time->length < 17)
-			return 0;
-
-		offset=N2(13)*3600+N2(15)*60;
-
-		if (asn1Time->data[12] == '-')
-			offset= -offset;
-	}
-
-#undef N2
-#undef CPY
-
-	return mktime(&tm)-offset;
-}
-
-static void dump_x509(X509 *x509, FILE *printx509_fp)
-{
-	X509_NAME *subj=X509_get_subject_name(x509);
-	int nentries, j;
-	time_t timestamp;
-	static const char gcc_shutup[]="%Y-%m-%d %H:%M:%S";
-
-	if (!subj)
-		return;
-
-	if (printx509_fp)
-		fprintf(printx509_fp, "Subject:\n");
-
-	nentries=X509_NAME_entry_count(subj);
-	for (j=0; j<nentries; j++)
-	{
-		const char *obj_name;
-		X509_NAME_ENTRY *e;
-		ASN1_OBJECT *o;
-		ASN1_STRING *d;
-
-		int dlen;
-		unsigned char *ddata;
-
-		e=X509_NAME_get_entry(subj, j);
-		if (!e)
-			continue;
-
-		o=X509_NAME_ENTRY_get_object(e);
-		d=X509_NAME_ENTRY_get_data(e);
-
-		if (!o || !d)
-			continue;
-
-		obj_name=OBJ_nid2sn(OBJ_obj2nid(o));
-
-		dlen=ASN1_STRING_length(d);
-		ddata=ASN1_STRING_data(d);
-
-		if (printx509_fp)
+		if (*p != '\n')
 		{
-			fprintf(printx509_fp, "   %s=", obj_name);
-			if (fwrite(ddata, dlen, 1, printx509_fp) == 1)
-				fprintf(printx509_fp, "\n");
+			if (dcs->line_size < sizeof(dcs->line)-1)
+				dcs->line[dcs->line_size++]=*p;
+
+			++p;
+			--cnt;
+			continue;
 		}
-	}
-	if (printx509_fp)
-		fprintf(printx509_fp, "\n");
+		dcs->line[dcs->line_size]=0;
+		++p;
+		--cnt;
+		dcs->line_size=0;
 
-	timestamp=asn1toTime(X509_get_notBefore(x509));
+		if (strncmp(dcs->line, "Subject:", 8) == 0)
+		{
+			if (dcs->seen_subject)
+				continue;
 
-	if (timestamp && printx509_fp)
-	{
-		struct tm *tm=localtime(&timestamp);
-		char buffer[500];
+			dcs->seen_subject=1;
+			dcs->in_subject=1;
+			continue;
+		}
 
-		buffer[strftime(buffer, sizeof(buffer)-1, gcc_shutup,
-				tm)]=0;
+		if (!dcs->in_subject)
+			continue;
 
-		fprintf(printx509_fp, "Not-Before: %s\n", buffer);
-	}
+		if (dcs->line[0] != ' ')
+		{
+			dcs->in_subject=0;
+			continue;
+		}
 
-	timestamp=asn1toTime(X509_get_notAfter(x509));
-	if (timestamp && printx509_fp)
-	{
-		struct tm *tm=localtime(&timestamp);
-		char buffer[500];
+		for (n=dcs->line; *n; n++)
+			if (*n != ' ')
+				break;
 
-		buffer[strftime(buffer, sizeof(buffer)-1, gcc_shutup,
-				tm)]=0;
+		for (v=n; *v; v++)
+		{
+			*v=toupper(*v);
+			if (*v == '=')
+			{
+				*v++=0;
+				break;
+			}
+		}
 
-		fprintf(printx509_fp, "Not-After: %s\n", buffer);
+		namebuf[snprintf(namebuf, sizeof(namebuf)-1,
+				 "TLS_SUBJECT_%s", n)]=0;
+
+		if (dcs->set_subject)
+			setenv(namebuf, v, 1);
 	}
 }
 
-static int verify_connection(SSL *ssl, void *dummy)
+static int verify_connection(ssl_handle ssl, void *dummy)
 {
 	FILE	*printx509_fp=NULL;
 	int	printx509_fd=0;
-	SSL_CIPHER *cipher;
+	char	*buf;
+
+	struct dump_capture_subject dcs;
+
+	memset(&dcs, 0, sizeof(dcs));
 
 	if (printx509)
 	{
@@ -340,75 +298,37 @@ static int verify_connection(SSL *ssl, void *dummy)
                         nonsslerror("fdopen");
 	}
 
+	dcs.fp=printx509_fp;
 
-	{
-		STACK_OF(X509) *peer_cert_chain=SSL_get_peer_cert_chain(ssl);
-		int i;
+	dcs.set_subject=0;
 
-		if (server)
-		{
-			X509 *x=SSL_get_peer_certificate(ssl);
+	if (tls_certificate_verified(ssl))
+		dcs.set_subject=1;
 
-			if (x)
-			{
-				dump_x509(x, printx509_fp);
-				X509_free(x);
-			}
-		}
-
-		for (i=0; peer_cert_chain && i<peer_cert_chain->stack.num; i++)
-			dump_x509((X509 *)peer_cert_chain->stack.data[i],
-				  printx509_fp);
-	}
-
-	cipher=SSL_get_current_cipher(ssl);
-
-	if (cipher)
-	{
-		static char protocolbuf[256];
-
-		const char *c;
-
-		c=SSL_CIPHER_get_version(cipher);
-		if (c && printx509_fp)
-			fprintf(printx509_fp, "Version: %s\n", c);
-
-		strcpy(protocolbuf, "TLS_CONNECTED_PROTOCOL=");
-		strncat(protocolbuf, c ? c:"unknown", 40);
-
-		if (printx509_fp)
-			fprintf(printx509_fp, "Bits: %d\n",
-				SSL_CIPHER_get_bits(cipher, NULL));
-
-		sprintf(protocolbuf+strlen(protocolbuf), ",%dbits",
-			SSL_CIPHER_get_bits(cipher, NULL));
-
-		c=SSL_CIPHER_get_name(cipher);
-
-		if (c && printx509_fp)
-			fprintf(printx509_fp, "Cipher: %s\n", c);
-
-		c=SSL_CIPHER_get_name(cipher);
-		strncat(strcat(protocolbuf, ","), c ? c:"unknown", 40);
-		putenv(protocolbuf);
-	}
+	tls_dump_connection_info(ssl, server ? 1:0, dump_to_fp, &dcs);
 
 	if (printx509_fp)
 	{
 		fclose(printx509_fp);
-		close(printx509_fd);
 	}
 
 	if (statusfp)
 	{
 		fclose(statusfp);
-		errfp=stderr;
 		statusfp=NULL;
+		errfp=stderr;
 	}
+
+	buf=tls_get_encryption_desc(ssl);
+
+	setenv("TLS_CONNECTED_PROTOCOL",
+	       buf ? buf:"(unknown)", 1);
+
+	if (buf)
+		free(buf);
 	return 1;
 }
 
-
 /* ----------------------------------------------------------------------- */
 
 static void startclient(int argn, int argc, char **argv, int fd,
@@ -543,7 +463,7 @@ int	port_num;
 	return (fd);
 }
 
-static int connect_completed(SSL *ssl, int fd)
+static int connect_completed(ssl_handle ssl, int fd)
 {
 	struct tls_transfer_info transfer_info;
 	tls_transfer_init(&transfer_info);
@@ -575,8 +495,8 @@ static int connect_completed(SSL *ssl, int fd)
 
 static int dossl(int fd, int argn, int argc, char **argv)
 {
-	SSL_CTX *ctx;
-	SSL	*ssl;
+	ssl_context ctx;
+	ssl_handle ssl;
 
 	int	stdin_fd, stdout_fd;
 	struct tls_info info= *tls_get_default_info();
@@ -598,7 +518,12 @@ static int dossl(int fd, int argn, int argc, char **argv)
 	}
 
 	if (!connect_completed(ssl, fd))
+	{
+		tls_disconnect(ssl, fd);
+		close(fd);
+		tls_destroy(ctx);
 		return 1;
+	}
 
 	stdin_fd=0;
 	stdout_fd=1;
@@ -828,7 +753,7 @@ void (*protocol_func)(int)=0;
 
 	setlocale(LC_ALL, "");
 	errfp=stderr;
- 
+
 	argn=argparse(argc, argv, arginfo);
 
 	if (statusfd)
@@ -872,5 +797,6 @@ void (*protocol_func)(int)=0;
 	if (fd < 0)	return (1);
 	if (protocol_func)
 		(*protocol_func)(fd);
+
 	return (dossl(fd, argn, argc, argv));
 }
