@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: attachments.c,v 1.47 2006/05/28 15:29:52 mrsam Exp $
+** $Id: attachments.c,v 1.48 2008/07/20 03:15:08 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -46,9 +46,7 @@
 #include	"maildir/maildirmisc.h"
 
 #include	"htmllibdir.h"
-#if	HAVE_SQWEBMAIL_UNICODE
 #include	"unicode/unicode.h"
-#endif
 
 extern char *newmsg_alladdrs(FILE *);
 extern void newmsg_copy_content_headers(FILE *fp);
@@ -105,9 +103,7 @@ const char	*quotaerr=getarg("QUOTAERR");
 const char	*limiterr=getarg("LIMITERR");
 off_t	dummy;
 int	fd2;
-#if	HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
-#endif
 
 	CHECKFILENAME(draft);
 	filename=maildir_find(INBOX "." DRAFTS, draft);
@@ -195,30 +191,18 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 		printf("<tr><td align=\"left\"><input type=\"checkbox\" name=\"del%d\" id=\"del%d\" />&nbsp;",
 			cnt, cnt);
 
-#if	HAVE_SQWEBMAIL_UNICODE
 		if (rfc2231_udecodeType(q, "name", uiptr, &content_name) < 0 ||
 		    rfc2231_udecodeDisposition(q, "filename", uiptr,
 					       &content_name) < 0)
 			content_name=NULL;
-#else
-		if (rfc2231_decodeType(q, "name", NULL, NULL, &content_name) < 0 ||
-		    rfc2231_decodeDisposition(q, "filename", NULL, NULL,
-					     &content_name) < 0)
-			content_name=NULL;
-#endif
 		if (!content_name &&
 		    ((cn=rfc2045_getattr(q->content_type_attr, "name")) ||
 		     (cn=rfc2045_getattr(q->content_disposition_attr,
 					 "filename"))) &&
 		    strstr(cn, "=?") && strstr(cn, "?="))
 		    /* RFC2047 header encoding (not compliant to RFC2047) */
-#if	HAVE_SQWEBMAIL_UNICODE
 			content_name = rfc2047_decode_unicode(cn, uiptr,
 				RFC2047_DECODE_ABORT);
-#else
-			content_name = rfc2047_decode_enhanced(cn,
-				sqwebmail_content_charset);
-#endif
 
 		if ((!content_name || !*content_name) &&
 		    strcmp(content_type, "application/pgp-keys") == 0)
@@ -265,7 +249,6 @@ void attachments_opts(const char *draft)
 		printf("<label><input type=\"checkbox\" name=\"dsn\" />%s</label><br />",
 		       getarg("DSN"));
 
-#if HAVE_SQWEBMAIL_UNICODE
 	if (libmail_gpg_has_gpg(GPGDIR) == 0)
 	{
 		char *all_addr;
@@ -294,7 +277,6 @@ void attachments_opts(const char *draft)
 		if (all_addr)
 			free(all_addr);
 	}
-#endif
 	fclose(fp);
 }
 
