@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: folder.c,v 1.182 2007/09/23 13:20:11 mrsam Exp $
+** $Id: folder.c,v 1.184 2008/07/20 17:00:33 mrsam Exp $
 */
 #include	"config.h"
 #include	<stdio.h>
@@ -71,9 +71,7 @@
 #endif
 #include	<errno.h>
 
-#if HAVE_SQWEBMAIL_UNICODE
 #include	"unicode/unicode.h"
-#endif
 
 #include	<unistd.h>
 #if HAVE_WCHAR_H
@@ -385,11 +383,9 @@ static void savepath(const char *path, const char *maildir)
 
 static void folder_msg_link(const char *, size_t, char);
 static void folder_msg_unlink(const char *, size_t, char);
-#if HAVE_SQWEBMAIL_UNICODE
 
 static char *truncate_at(const char *, const struct unicode_info *, size_t);
 
-#endif
 
 void folder_contents(const char *dir, size_t pos)
 {
@@ -400,12 +396,10 @@ const char	*nomsg, *selectalllab;
 const char	*unselectalllab, *golab;
 const char	*qerrmsg;
 long highend;
-#if HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 
 	if (!uiptr)
 		uiptr=&unicode_ISO8859_1;
-#endif
 
 	qerrmsg=getarg("PERMERR");
 
@@ -456,7 +450,6 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 		getarg("SUBJECT"),
 		getarg("SIZE"));
 
-	setlocale(LC_CTYPE, sqwebmail_content_locale); // for wcwidth()
 	found=0;
 	for (i=0; i<pref_flagpagesize; i++)
 	{
@@ -522,16 +515,9 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 		if (!*from)	from=" ";
 		folder_msg_link(dir, pos+i, type[0]);
 
-#if HAVE_SQWEBMAIL_UNICODE
 
 		froms=truncate_at(from, uiptr, 30);
 
-#else
-		froms=rfc2047_decode_enhanced(from,
-					      sqwebmail_content_charset);
-		if (froms && strlen(froms) >= 30)
-			strcpy(froms+27, "...");
-#endif
 		if (froms == 0)	enomem();
 
 		print_safe(froms);
@@ -542,17 +528,9 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 
 		folder_msg_link(dir, pos+i, type[0]);
 
-#if HAVE_SQWEBMAIL_UNICODE
 
 		subjs=truncate_at(subj, uiptr, 40);
 
-#else
-		subjs=rfc2047_decode_enhanced(subj,
-					      sqwebmail_content_charset);
-
-		if (subjs && strlen(subjs) >= 40)
-			strcpy(subjs+37, "...");
-#endif
 		if (subjs == 0)	enomem();
 
 		print_safe(subjs);
@@ -565,8 +543,6 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 		printf("%s</td><td align=\"right\" class=\"message-size\">%s%s&nbsp;%s<br /></td></tr>\n", folder_index_entry_end, folder_index_entry_start, size, folder_index_entry_end);
 	}
 
-	setlocale(LC_CTYPE, "C");
-
 	if (found)
 	{
 		puts("<tr class=\"folder-index-bg-1\"><td colspan=\"6\"><hr /></td></tr>");
@@ -787,9 +763,7 @@ void folder_initnextprev(const char *dir, size_t pos)
 	const	char *p;
 	const	char *msg_numlab, *msg_numnewlab;
 	static char *filename=0;
-#if HAVE_SQWEBMAIL_UNICODE
 	int fd;
-#endif
 
 	cgi_put(MIMEGPGFILENAME, "");
 
@@ -797,7 +771,6 @@ void folder_initnextprev(const char *dir, size_t pos)
 		free(filename);
 	filename=0;
 
-#if HAVE_SQWEBMAIL_UNICODE
 
 	if (*cgi("mimegpg") && (filename=maildir_posfind(dir, &pos)) != 0)
 	{
@@ -854,7 +827,6 @@ void folder_initnextprev(const char *dir, size_t pos)
 			close(fd);
 		}
 	}
-#endif
 
 	initnextprevcnt=0;
 	msg_nextlab=getarg("NEXTLAB");
@@ -1359,20 +1331,15 @@ static int is_preview_mode()
 	return (*cgi("showdraft"));
 }
 
-#if HAVE_SQWEBMAIL_UNICODE
 static void dokeyimport(FILE *, struct rfc2045 *, int);
-#endif
 
 void charset_warning(const char *mime_charset)
 {
-#if HAVE_SQWEBMAIL_UNICODE
 	const struct unicode_info *u1, *u2;
-#endif
 
 	if (strcasecmp(mime_charset, "us-ascii") == 0)
 		return;
 
-#if HAVE_SQWEBMAIL_UNICODE
 	u1=unicode_find(mime_charset);
 	u2=unicode_find(sqwebmail_content_charset);
 
@@ -1380,9 +1347,6 @@ void charset_warning(const char *mime_charset)
 		return;
 
 	if (!u1 || !u2 || strcmp(u1->chset, u2->chset))
-#else
-       	if (strcasecmp(mime_charset, sqwebmail_content_charset))
-#endif
 	{
 		printf(getarg("CHSET"), mime_charset,
 		       sqwebmail_content_charset);
@@ -1450,13 +1414,11 @@ static void init_smileys(struct msg2html_info *info)
 
 static void email_address_start(const char *name, const char *addr)
 {
-#if HAVE_SQWEBMAIL_UNICODE
 	const struct unicode_info *uiptr=
 		unicode_find(sqwebmail_content_charset);
 
 	if (!uiptr)
 		uiptr=&unicode_ISO8859_1;
-#endif
 
 	if (is_preview_mode())
 	    return;
@@ -1468,13 +1430,8 @@ static void email_address_start(const char *name, const char *addr)
 
 	if (name)
 	{
-#if HAVE_SQWEBMAIL_UNICODE
 		char *v=rfc2047_decode_unicode(name, uiptr,
 					       RFC2047_DECODE_REPLACE);
-#else
-		char *v=rfc2047_decode_enhanced(name,
-						sqwebmail_content_charset);
-#endif
 		if (v)
 		{
 			output_urlencoded(v);
@@ -2066,7 +2023,6 @@ void folder_keyimport(const char *dir, size_t pos)
 	rfc=rfc2045_fromfp(fp);
 
 
-#if HAVE_SQWEBMAIL_UNICODE
 	if (libmail_gpg_has_gpg(GPGDIR) == 0)
 	{
 		struct rfc2045 *part;
@@ -2082,7 +2038,6 @@ void folder_keyimport(const char *dir, size_t pos)
 			dokeyimport(fp, part, 1);
 		}
 	}
-#endif
 	rfc2045_free(rfc);
 	fclose(fp);
 	free(filename);
@@ -2093,7 +2048,6 @@ void folder_keyimport(const char *dir, size_t pos)
 	printf("\">%s</a>", getarg("KEYIMPORT"));
 }
 
-#if HAVE_SQWEBMAIL_UNICODE
 static int importkey_func(const char *p, size_t cnt, void *voidptr);
 static int importkeyin_func(const char *p, size_t cnt, void *voidptr);
 
@@ -2163,7 +2117,6 @@ static int importkey_func(const char *p, size_t cnt, void *voidptr)
 	return (0);
 }
 
-#endif
 
 /*
 ** If we're currently showing (INBOX|shared|#shared).foo.bar hierarchy, return
@@ -3473,7 +3426,6 @@ folder_cleanup()
 	msg_count=0;
 }
 
-#if HAVE_SQWEBMAIL_UNICODE
 
 /*
 ** Unicode-aware truncation of text at a specified column, if text length
@@ -3502,21 +3454,9 @@ static char *truncate_at(const char *str,
 	}
 
 	for (cols=0, n=0; uc[n]; n++) {
-#if HAVE_WCWIDTH
-		int cw=wcwidth(uc[n]);
 
-		if (cw <= 0)
-			cw=1;
+		cols += unicode_wcwidth(uc[n]);
 
-		cols += cw;
-#else
-		if (uc[n] == (unicode_char)0x0FFFD)
-			cols++;
-		else if (uc[n] >= (unicode_char)0x0800)
-			cols+=2;
-		else
-			cols++;
-#endif
 		if (!tp && cols > ncols-3)
 			tp = n;
 	}
@@ -3540,4 +3480,3 @@ static char *truncate_at(const char *str,
 	return uibuf;
 }
 
-#endif
