@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: maildir.c,v 1.87 2006/05/29 13:31:15 mrsam Exp $
+** $Id: maildir.c,v 1.88 2008/07/20 03:15:08 mrsam Exp $
 */
 #include	"config.h"
 #include	<stdio.h>
@@ -37,9 +37,7 @@
 #if	HAVE_UNISTD_H
 #include	<unistd.h>
 #endif
-#if HAVE_SQWEBMAIL_UNICODE
 #include	"unicode/unicode.h"
-#endif
 
 #if	HAVE_DIRENT_H
 #include	<dirent.h>
@@ -1483,13 +1481,8 @@ static int subjectcmp(const char *a, const char *b)
 	char	*as;
 	char	*bs;
 
-#if HAVE_SQWEBMAIL_UNICODE
 	as=rfc2047_decode_unicode(a, &unicode_UTF8, 0);
 	bs=rfc2047_decode_unicode(b, &unicode_UTF8, 0);
-#else
-	as=rfc2047_decode_simple(a);
-	bs=rfc2047_decode_simple(b);
-#endif
 
 	if (as)
 	{
