@@ -1,5 +1,5 @@
 /*
-** $Id: mailfilter.c,v 1.19 2006/07/01 00:37:09 mrsam Exp $
+** $Id: mailfilter.c,v 1.20 2006/09/09 01:24:09 mrsam Exp $
 */
 
 /*
@@ -399,6 +399,7 @@ const char *rulename=0;
 const char *fieldname=0;
 const char *fieldvalue=0;
 char *tofolder=0;
+char *fieldname_cpy;
 int	err_num;
 char	numbuf[NUMBUFSIZE];
 const char *autoreply_from="";
@@ -556,13 +557,29 @@ const char *autoreply_from="";
 		if (!tofolder)	enomem();
 	}
 
+	fieldname_cpy=NULL;
+
+	if (fieldname)
+	{
+		char *p;
+
+		fieldname_cpy=strdup(fieldname);
+
+		p=strrchr(fieldname_cpy, ':');
+
+		if (p && p[1] == 0)
+			*p=0;
+	}
+
 	if (!r)
-		r=maildir_filter_appendrule(&mf, rulename, type, flags, fieldname,
+		r=maildir_filter_appendrule(&mf, rulename, type, flags, fieldname_cpy,
 			fieldvalue, tofolder, autoreply_from, &err_num);
-	else if (maildir_filter_ruleupdate(&mf, r, rulename, type, flags, fieldname,
+	else if (maildir_filter_ruleupdate(&mf, r, rulename, type, flags, fieldname_cpy,
 			fieldvalue, tofolder, autoreply_from, &err_num))
 		r=0;
 	free(tofolder);
+	if (fieldname_cpy)
+		free(fieldname_cpy);
 	if (r)
 	{
 		maildir_filter_savemaildirfilter(&mf, ".", login_returnaddr());
