@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: newmsg_create.c,v 1.62 2007/09/02 19:59:38 mrsam Exp $
+** $Id: newmsg_create.c,v 1.64 2008/07/20 17:00:33 mrsam Exp $
 */
 #include	"config.h"
 #include	"cgi/cgi.h"
@@ -828,13 +828,9 @@ static void lookup_addressbook(const char *header, const char *value)
 {
 struct lookup_buffers *lookup_buffer_list=0;
 int	rc;
-#if	HAVE_SQWEBMAIL_UNICODE
 const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 char	*s=rfc2047_decode_unicode(value, uiptr,
 				  RFC2047_DECODE_NOTAG|RFC2047_DECODE_REPLACE);
-#else
-char	*s=rfc2047_decode_simple(value);
-#endif
 
 	if (!s)	enomem();
 	rc=lookup_addressbook_do(header, s, &lookup_buffer_list);
@@ -1037,7 +1033,6 @@ int has_wikifmt=0;
 		return (0);
 	}
 
-#if HAVE_SQWEBMAIL_UNICODE
 	if (libmail_gpg_has_gpg(GPGDIR) == 0)
 	{
 		char dosign= *cgi("sign");
@@ -1120,7 +1115,6 @@ int has_wikifmt=0;
 		}
 		free(encryptkeys);
 	}
-#endif
 
 	if ( maildir_closemsg(newdraftfd, INBOX "." SENT, sentname, 1, 0))
 	{
@@ -1343,6 +1337,17 @@ static void sentmsg_reformat(FILE *f, struct rfc2045 *p, int do_footer,
 	FILE	*fp;
 	struct libmail_encode_info encode_info;
 	struct rfc2646create *createptr;
+	const char *content_type, *content_transfer_encoding, *charset;
+	const struct unicode_info *ucharset;
+
+	rfc2045_mimepos(p, &start_pos, &end_pos, &start_body,
+		&dummy, &dummy);
+	rfc2045_mimeinfo(p, &content_type, &content_transfer_encoding,
+			 &charset);
+
+	ucharset=unicode_find(charset);
+	if (!ucharset)
+		ucharset=&unicode_ISO8859_1;
 
 	rfc2045_mimepos(p, &start_pos, &end_pos, &start_body,
 		&dummy, &dummy);
@@ -1356,7 +1361,8 @@ static void sentmsg_reformat(FILE *f, struct rfc2045 *p, int do_footer,
 	libmail_encode_start(&encode_info, transfer_encoding, &write_to_draft,
 			     NULL);
 
-	createptr=rfc2646create_alloc( &write_to_draft_encode, &encode_info);
+	createptr=rfc2646create_alloc( &write_to_draft_encode,
+				       ucharset, &encode_info);
 	if (!createptr)
 	{
 		fclose(f);
