@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: newmsg_newdraft.c,v 1.39 2004/05/23 14:28:24 mrsam Exp $
+** $Id: newmsg_newdraft.c,v 1.40 2008/07/20 03:15:08 mrsam Exp $
 */
 #include	"config.h"
 #include	"cgi/cgi.h"
@@ -181,11 +181,7 @@ int	x;
 		if (strcmp(replymode, "forward") == 0
 		    || strcmp(replymode, "forwardatt") == 0)
 		{
-#if	HAVE_SQWEBMAIL_UNICODE
 			rc=rfc2045_makereply_unicode(&ri);
-#else
-			rc=rfc2045_makereply(&ri);
-#endif
 		}
 		else
 		{
@@ -199,11 +195,7 @@ int	x;
 			free(basename);
 			maildir_writemsgstr(draftfd, "\n");
 
-#if	HAVE_SQWEBMAIL_UNICODE
 			rc=rfc2045_makereply_unicode(&ri);
-#else
-			rc=rfc2045_makereply(&ri);
-#endif
 		}
 		free(ml);
 
