@@ -1,11 +1,11 @@
 /*
-** Copyright 2001-2004 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: pcp.c,v 1.29 2006/03/12 13:56:53 mrsam Exp $
+** $Id: pcp.c,v 1.30 2006/05/28 15:29:52 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"pcp.h"
@@ -2677,8 +2677,7 @@ static void proxy_notify_email_msg(FILE *f, struct proxy_list_entry *l,
 
 	if (p == 0)
 	{
-		close(0);
-		dup(pipefd[0]);
+		dup2(pipefd[0], 0);
 		close(pipefd[0]);
 		close(pipefd[1]);
 		execl(SENDITSH, "sendit.sh", returnaddr,
