@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: sqispell.c,v 1.22 2006/07/22 21:54:00 mrsam Exp $
+** $Id: sqispell.c,v 1.23 2007/05/06 21:49:29 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"maildir.h"
@@ -372,7 +372,7 @@ char	*w;
 	return (newline);
 }
 
-static void showfunc(const char *p, size_t n)
+static void showfunc(const char *p, size_t n, void *dummy)
 {
 	while (n)
 	{
@@ -458,14 +458,26 @@ const char *finishlab=getarg("FINISH");
 	}
 	else
 		p=0;
-	filter_start(FILTER_FOR_DISPLAY, &showfunc);
-	filter(ispellline+p, msp->word_pos-p);
-	filter_end();
-	printf("<strong>");
-	filter_start(FILTER_FOR_DISPLAY, &showfunc);
-	filter(ispellline+msp->word_pos, strlen(msp->misspelled_word));
-	filter_end();
-	printf("</strong>");
+
+
+	{
+		struct filter_info info;
+
+		filter_start(&info, FILTER_FOR_DISPLAY, &showfunc, NULL);
+		filter(&info, ispellline+p, msp->word_pos-p);
+		filter_end(&info);
+	}
+
+	{
+		struct filter_info info;
+
+		printf("<strong>");
+		filter_start(&info, FILTER_FOR_DISPLAY, &showfunc, NULL);
+		filter(&info, ispellline+msp->word_pos, strlen(msp->misspelled_word));
+		filter_end(&info);
+		printf("</strong>");
+	}
+
 	p=msp->word_pos+strlen(msp->misspelled_word);
 	if (l-p < 30)
 	{
@@ -484,9 +496,15 @@ const char *finishlab=getarg("FINISH");
 			--n;
 		break;
 	}
-	filter_start(FILTER_FOR_DISPLAY, &showfunc);
-	filter(ispellline+p, n);
-	filter_end();
+
+	{
+		struct filter_info info;
+
+		filter_start(&info, FILTER_FOR_DISPLAY, &showfunc, NULL);
+		filter(&info, ispellline+p, n);
+		filter_end(&info);
+	}
+
 	if (n != l-p)
 		printf("&nbsp;...");
 	printf("</span></td></tr></table><br />");
